import _extends from "@babel/runtime/helpers/extends";
import { engineConfig } from '@alilc/lowcode-editor-core';
import { intlNode } from './locale';
import { IconLock, IconUnlock, IconRemove, IconClone, IconHidden } from './icons';
import { componentDefaults, legacyIssues } from './transducers';
export var ComponentActions = /*#__PURE__*/function () {
  function ComponentActions() {
    this.actions = [{
      name: 'remove',
      content: {
        icon: IconRemove,
        title: intlNode('remove'),
        /* istanbul ignore next */action: function action(node) {
          node.remove();
        }
      },
      important: true
    }, {
      name: 'hide',
      content: {
        icon: IconHidden,
        title: intlNode('hide'),
        /* istanbul ignore next */action: function action(node) {
          node.setVisible(false);
        }
      },
      /* istanbul ignore next */
      condition: function condition(node) {
        return node.componentMeta.isModal;
      },
      important: true
    }, {
      name: 'copy',
      content: {
        icon: IconClone,
        title: intlNode('copy'),
        /* istanbul ignore next */action: function action(node) {
          // node.remove();
          var doc = node.document,
            parent = node.parent,
            index = node.index;
          if (parent) {
            var newNode = doc.insertNode(parent, node, index + 1, true);
            newNode.select();
            var _node$getRGL = node.getRGL(),
              isRGL = _node$getRGL.isRGL,
              rglNode = _node$getRGL.rglNode;
            if (isRGL) {
              // 复制 layout 信息
              var layout = rglNode.getPropValue('layout') || [];
              var curLayout = layout.filter(function (item) {
                return item.i === node.getPropValue('fieldId');
              });
              if (curLayout && curLayout[0]) {
                layout.push(_extends({}, curLayout[0], {
                  i: newNode.getPropValue('fieldId')
                }));
                rglNode.setPropValue('layout', layout);
                // 如果是磁贴块复制，则需要滚动到影响位置
                setTimeout(function () {
                  var _newNode$document$sim;
                  return (_newNode$document$sim = newNode.document.simulator) === null || _newNode$document$sim === void 0 ? void 0 : _newNode$document$sim.scrollToNode(newNode);
                }, 10);
              }
            }
          }
        }
      },
      important: true
    }, {
      name: 'lock',
      content: {
        icon: IconLock,
        // 锁定 icon
        title: intlNode('lock'),
        /* istanbul ignore next */action: function action(node) {
          node.lock();
        }
      },
      /* istanbul ignore next */
      condition: function condition(node) {
        return engineConfig.get('enableCanvasLock', false) && node.isContainer() && !node.isLocked;
      },
      important: true
    }, {
      name: 'unlock',
      content: {
        icon: IconUnlock,
        // 解锁 icon
        title: intlNode('unlock'),
        /* istanbul ignore next */action: function action(node) {
          node.lock(false);
        }
      },
      /* istanbul ignore next */
      condition: function condition(node) {
        return engineConfig.get('enableCanvasLock', false) && node.isContainer() && node.isLocked;
      },
      important: true
    }];
    this.metadataTransducers = [];
    this.registerMetadataTransducer(legacyIssues, 2, 'legacy-issues'); // should use a high level priority, eg: 2
    this.registerMetadataTransducer(componentDefaults, 100, 'component-defaults');
  }
  var _proto = ComponentActions.prototype;
  _proto.removeBuiltinComponentAction = function removeBuiltinComponentAction(name) {
    var i = this.actions.findIndex(function (action) {
      return action.name === name;
    });
    if (i > -1) {
      this.actions.splice(i, 1);
    }
  };
  _proto.addBuiltinComponentAction = function addBuiltinComponentAction(action) {
    this.actions.push(action);
  };
  _proto.modifyBuiltinComponentAction = function modifyBuiltinComponentAction(actionName, handle) {
    var builtinAction = this.actions.find(function (action) {
      return action.name === actionName;
    });
    if (builtinAction) {
      handle(builtinAction);
    }
  };
  _proto.registerMetadataTransducer = function registerMetadataTransducer(transducer, level, id) {
    if (level === void 0) {
      level = 100;
    }
    transducer.level = level;
    transducer.id = id;
    var i = this.metadataTransducers.findIndex(function (item) {
      return item.level != null && item.level > level;
    });
    if (i < 0) {
      this.metadataTransducers.push(transducer);
    } else {
      this.metadataTransducers.splice(i, 0, transducer);
    }
  };
  _proto.getRegisteredMetadataTransducers = function getRegisteredMetadataTransducers() {
    return this.metadataTransducers;
  };
  return ComponentActions;
}();